ProgressIndicator class

Constructors

ProgressIndicator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(String message) → void
Stops the spinner and shows an error message.
info(String message) → void
Shows an info message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printFinalSuccess(String message) → void
Prints a final success message.
printSummaryHeader() → void
Prints a summary header.
start(String message) → void
Starts a spinner with a message.
stop() → void
Stops the spinner immediately without any status.
success(String message) → void
Stops the spinner and shows a success message.
toString() String
A string representation of this object.
inherited
warning(String message) → void
Shows a warning message.

Operators

operator ==(Object other) bool
The equality operator.
inherited