ConfigLoader class

Constructors

ConfigLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exists() bool
Checks if the configuration file exists.
load() GeneratorConfig
Loads configuration from the YAML file if it exists. Returns a GeneratorConfig with default values if the file is missing or invalid.

Constants

fileName → const String