JsonParser class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
Extracts the base object for model generation.
If the input is a list, returns the first element if available.
-
parseFile(String filePath)
→ dynamic
-
Reads a JSON file and returns a Map or List