ModelBuilder class
Constructors
-
ModelBuilder(String modelName, Map<
String, dynamic> json, [ModelRegistry? registry])
Properties
Methods
-
build(
) → String - Generates the complete Dart code for the model class
-
getAllModels(
) → List< ModelBuilder> - Recursively finds and creates nested model builders
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited