ServiceGenerator class

Constructors

ServiceGenerator({required String modelName, required bool isList, required String modelFileName})

Properties

hashCode int
The hash code for this object.
no setterinherited
isList bool
final
modelFileName String
final
modelName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() String
Generates the service class code
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited