InteractiveCLI class
Constructors
- InteractiveCLI(GeneratorConfig config)
Properties
- config → GeneratorConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startApiGenerate(
) → void - API Client Generation
-
startBatch(
String folderPath) → void - Batch Generation
-
startGenerate(
) → void - Generate based on config file
-
startInteractive(
) → void - Default interactive mode
-
startSync(
) → void - Direct sync mode
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited