ApiEndpoint class
Constructors
- ApiEndpoint({required String name, required String method, required String path, String? requestModel, required String responseModel, required String responseType})
- ApiEndpoint.fromYaml(YamlMap map)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
final
- name → String
-
final
- path → String
-
final
- requestModel → String?
-
final
- responseModel → String
-
final
- responseType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited