GeneratorConfig class
Constructors
-
GeneratorConfig({String modelsPath = 'lib/models', String servicesPath = 'lib/services', String repositoriesPath = 'lib/repositories', String apiPath = 'lib/api', bool generateService = false, bool generateRepository = false, String httpClient = 'http', String? baseUrl, List<
ApiEndpoint> endpoints = const []}) - GeneratorConfig.fromYaml(String yamlContent)
-
factory
Properties
- apiPath → String
-
final
- baseUrl → String?
-
final
-
endpoints
→ List<
ApiEndpoint> -
final
- generateRepository → bool
-
final
- generateService → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClient → String
-
final
- modelsPath → String
-
final
- repositoriesPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- servicesPath → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited